@@ -15,5 +15,10 @@ int main(int argc, char *argv[])
     w.show();
 #endif
 
+    if(argc==2)
+    {
+        w.uploadFileCommand(argv[1]);
+    }
+
     return a.exec();
 }
