@@ -8,7 +8,6 @@
 #if defined(Q_WS_MAEMO_5)
     #include <QMaemo5InformationBox>
 #endif
-#include <QtGui>
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
@@ -65,7 +64,7 @@ void MainWindow::updateLabel(QString label, QString value)
     } else if (label=="speed") {
         ui->lblSpeed->setText(value.trimmed().append(" KB/s"));
     } else if (label=="state" || label=="status") {
-        ui->lblStatus->setText(ucfirst(value));
+        ui->lblStatus->setText(ucfirst(value.toLower()));
     } else {
         qDebug() << "Unknown label: "+label+":"+value;
     }
@@ -136,12 +135,13 @@ void MainWindow::showError(QString error)
 }
 
 void MainWindow::updateHistoryList(QMap<QString,QMap<QString,QString > > historyitems)
-{
+{    
     qDebug() << "updateHistoryList";
     ui->lstHistory->show();
     ui->lstDownloads->hide();
 
     ui->lstHistory->clear();
+    historyitemcache.clear();
 
     QDateTime timestamp;
     QMapIterator<QString, QMap<QString,QString> > i(historyitems);
@@ -159,6 +159,13 @@ void MainWindow::updateHistoryList(QMap<QString,QMap<QString,QString > > history
         item->setText(1,download["size"]);
         item->setText(2,download["status"]);
         item->setText(3,timestamp.toString(Qt::SystemLocaleDate));
+        //int index = ui->lstHistory->indexFromItem(item).row();
+        int index = ui->lstHistory->indexOfTopLevelItem ( item);
+
+
+        //ui->lstHistory->mo
+
+        historyitemcache.insert(index,download);
     }
     for(int i = 0; i< ui->lstHistory->columnCount(); i++)
         ui->lstHistory->resizeColumnToContents(i);
@@ -186,3 +193,18 @@ void MainWindow::uploadFileCommand(char* file)
         sc.addNZB(filename);
 }
 
+void MainWindow::on_pbStatus_clicked()
+{
+
+}
+
+void MainWindow::on_lstHistory_itemClicked(QTreeWidgetItem* item, int column)
+{
+    qDebug() << "on_lstHistory_itemClicked";
+    HistoryDetails hd(this);
+    int index = ui->lstHistory->indexOfTopLevelItem ( ui->lstHistory->currentItem());
+    hd.setHistoryInfo(historyitemcache[index]);
+    hd.exec();
+
+    qDebug() << "on_lstHistory_itemClicked end";
+}
