@@ -3,6 +3,8 @@
 
 #include <QMainWindow>
 #include "sabconnector.h"
+#include "historydetails.h"
+#include <QtGui>
 
 namespace Ui {
     class MainWindow;
@@ -21,8 +23,11 @@ private:
     Ui::MainWindow *ui;
     SabConnector sc;
     QString ucfirst(const QString);
+    QMap<int ,QMap<QString,QString > > historyitemcache;
 
 private slots:
+    void on_lstHistory_itemClicked(QTreeWidgetItem* item, int column);
+    void on_pbStatus_clicked();
     void on_pbHistory_clicked();
     void on_pbAdd_clicked();
     void on_pbRefresh_clicked();
