@@ -13,7 +13,6 @@ QString Settings::getAPIkey()
 {
     qDebug() << "getAPIkey";
     return m_settings.value("apikey","").toString();
-    //return QString("d2a505eb2ce1dd352f45ca656e5991a6");
 }
 
 bool Settings::setAPIkey(QString apikey)
@@ -48,9 +47,33 @@ QString Settings::getAdress()
 {
     qDebug() << "getAdress";
     return m_settings.value("address","localhost").toString();
-    //return QString("linuxbak.peejseej.nl");
 }
 
+QString Settings::getUsername()
+{
+    qDebug() << "getUsername";
+    return m_settings.value("username","").toString();
+}
+
+bool Settings::setUsername(QString username)
+{
+    m_settings.setValue("username",username);
+    return true;
+}
+
+QString Settings::getPassword()
+{
+    qDebug() << "getPassword";
+    return m_settings.value("password","").toString();
+}
+
+bool Settings::setPassword(QString password)
+{
+    m_settings.setValue("password",password);
+    return true;
+}
+
+
 bool Settings::setAddress(QString adress)
 {
     qDebug() << "setAddress: "+adress;
