@@ -13,6 +13,10 @@ public:
     bool setAddress(QString);
     int getPort();
     bool setPort(QString);
+    QString getUsername();
+    bool setUsername(QString);
+    QString getPassword();
+    bool setPassword(QString);
     Settings();
     ~Settings();
 };
