@@ -13,9 +13,13 @@ class SettingsDialog : public QDialog
     QLabel *adress;
     QLabel *apikey;
     QLabel *port;
+    QLabel *username;
+    QLabel *password;
     QLineEdit *lineEditAddr;
     QLineEdit *lineEditApi;
     QLineEdit *lineEditPort;
+    QLineEdit *lineEditUsername;
+    QLineEdit *lineEditPassword;
     QPushButton *saveButton;
     QPushButton *testButton;
 
